@@ -24,6 +24,15 @@
 ##
 ## a set of itemsets, subclass of associations
 
+itemsets <- function(items, itemLabels, quality = data.frame()) {
+  if (!is(items, "itemMatrix")) items <- encode(items, itemLabels = itemLabels)
+  
+  new("itemsets", 
+    items = items,
+    quality = quality
+  )
+}
+
 
 ##************************************************
 ## dimensions
